@@ -9,11 +9,15 @@ import threading
 import time
 import sys
 
-from .static import static_analysis, sync_profiles_from_tar
+from .general import sync_policies, sync_profiles_from_tar, check_cinc_installed, check_saf_installed
+from .static import static_analysis
 from .vm import run_stig_over_ssh
-from .runtime import runtime_analysis, check_saf_installed, saf_convert_output, sync_policies
+from .runtime import runtime_analysis, saf_convert_output
 from .inputs import collect_inputs, runtime_get_image_digest, get_runtime_cluster
 from .provision import install_cinc, install_train_plugin
+from .generate import generate_input_file
+from .review import validate_file, create_output_rollup
+from anchorestig import __version__
 
 @click.group()
 def main():
@@ -40,6 +44,7 @@ def static(username, password, url, insecure, image, aws_bucket, account, profil
     if sync_from_file:
         sync_profiles_from_tar(sync_from_file)
         print("Policies successfully updated.")
+    check_cinc_installed()
     check_saf_installed()
     if not input_file:
         input_file = "default"
@@ -76,6 +81,10 @@ def runtime(image, pod, container, outfile, namespace, usecontext, aws_bucket, a
     """Run runtime analysis"""
     print("Runtime Analysis")
     aws = aws_bucket
+    if not aws:
+        aws = "skip_upload"
+    if not account:
+        account = "skip_upload"
     if sync:
         sync_policies()
         print("Policies successfully downloaded.")
@@ -107,6 +116,7 @@ def runtime(image, pod, container, outfile, namespace, usecontext, aws_bucket, a
 @click.option('--profile', '-l', default="indeterminate", help="Specify profile to run. Can be the name of an existing profile or the path to a custom profile. Existing profile are Available options are ubuntu2004, ubuntu2204, ubi8, ubi9, postgres9, apache-tomcat9, crunchy-postgresql, jboss, jre7, mongodb, nginx", required=True)
 @click.option('--input-file', '-i', help="Specify the path to a custom input file to run with a profile.")
 def vm(user, password, key, host, profile, input_file):
+    """Run vm analysis"""
     if not input_file:
         input_file = "default"
     done = False
@@ -129,15 +139,62 @@ def vm(user, password, key, host, profile, input_file):
 @click.option("--privileged", "-s", is_flag=True, default=False, help="Install CINC with sudo.")
 @click.option("--plugin", "-p", is_flag=True, default=False, help="Install the CINC Train K8S Plugin")
 def provision(install, privileged, plugin):
+    """Install required tools - Please note this tool is experimental. Refer to documentation for instructions about installing required tooling."""
     if install:
         install_cinc(privileged)
     if plugin:
         install_train_plugin()
 
+@click.command()
+@click.argument('profile_name', required=False)
+def generate(profile_name):
+    """Generate an example inputs file. Note: the generated file will be the default file used if no input file is specified."""
+    profile_list = """
+    Profile name required. Please specify one of the following as an argument.
+    Available profile names:
+    apache-tomcat9
+    crunchy-postgresql
+    jboss
+    jre7
+    mongodb
+    nginx
+    postgres9
+    ubi8
+    ubi9
+    ubuntu2004
+    ubuntu2204
+    """
+    available_profiles = ["apache-tomcat9", "crunchy-postgresql", "jboss", "jre7", "mongodb", "nginx", "postgres9", "ubi8", "ubi9", "ubuntu2004", "ubuntu2204"]
+    if not profile_name:
+        print(profile_list)
+    elif profile_name not in available_profiles:
+        print(profile_list)
+    else:
+        generate_input_file(profile_name)
+
+@click.command()
+@click.argument('output_file_path', required=True)
+def review(output_file_path):
+    """Generates an in-terminal rollup of a STIG result file"""
+    valid_file = validate_file(output_file_path)
+    if not valid_file:
+        print("Input file is not valid, please try again.")
+        exit()
+    else:
+        create_output_rollup(output_file_path)
+
+@click.command()
+def version():
+    """Print the current version of Anchore STIG"""
+    print(__version__)
+
 main.add_command(static)
 main.add_command(runtime)
 main.add_command(provision)
 main.add_command(vm)
+main.add_command(generate)
+main.add_command(version)
+main.add_command(review)
 
 if __name__ == '__main__':
     main()
