@@ -17,25 +17,6 @@ def usage():
     print("Usage: anchorestig static <IMAGE> [-u registry_username] [-p registry_password] [-r registry_url] [-s] [-b AWS S3 Bucket name] [-a Anchore STIG UI Account] [-l STIG Profile nae or path] [-i Input File for STIG]")
     exit(1)
 
-def sync_profiles_from_tar(tar_path):
-    package_name = "anchorestig"
-    spec = importlib.util.find_spec(package_name)
-    package_root_directory = os.path.dirname(spec.origin)
-    try:
-        file = tarfile.open(tar_path)
-        file.extractall(f"{package_root_directory}")
-    except Exception:
-        print("Unable to extract tarred policies. Please try again.")
-        exit()
-
-def start_container(image):
-    command = ['docker', 'run', '--rm', '-t', '-d', '--entrypoint="sh"', image]
-    try:
-        result = subprocess.run(command, shell=True, capture_output=True, text=True)
-        return result.stdout.strip()
-    except Exception:
-        print(f"Unable to sandbox image: {result.stderr}")
-
 def stop_container(container_id):
     command = ['docker', 'kill', container_id]
     try:
@@ -85,19 +66,35 @@ def upload_to_s3(bucket_name, file, account, image_digest, image_name):
         print(f"Error: {e}")
 
 def get_image_digest(image, username, password, url, insecure):
-    if not username:
-        subprocess.run(["docker", "pull", image])
-        result = subprocess.run(["docker", "inspect", '--format="{{index .RepoDigests 0}}"', image], capture_output = True, text = True)
-        print(result.stdout.split('@')[-1].replace('"', ''))
-        subprocess.run(["docker", "rmi", image])
-        return result.stdout.split('@')[-1].replace('"', '')
-    else:
-        subprocess.run(["docker", "--config", "./stig-docker-config", "login", url, "-u", username, "-p", password])
-        subprocess.run(["docker", "pull", image])
-        result = subprocess.run(["docker", "inspect", '--format="{{index .RepoDigests 0}}"', image], capture_output = True, text = True)
-        print(result.stdout.split('@')[-1].replace('"', ''))
-        subprocess.run(["docker", "rmi", image])
-        return result.stdout.split('@')[-1].replace('"', '')
+    try:
+        if not username:
+            pull_cmd = ["docker", "pull", image]
+        else:
+            subprocess.run(["docker", "--config", "./stig-docker-config", "login", url, "-u", username, "-p", password], check=True)
+            pull_cmd = ["docker", "pull", image]
+
+        # Try to pull the image
+        pull_result = subprocess.run(pull_cmd, capture_output=True, text=True)
+        if pull_result.returncode != 0:
+            raise RuntimeError(f"Failed to pull image {image}: {pull_result.stderr.strip()}")
+
+        # Try to inspect the image digest
+        inspect_result = subprocess.run(["docker", "inspect", '--format={{index .RepoDigests 0}}', image], capture_output=True, text=True)
+        if inspect_result.returncode != 0 or not inspect_result.stdout.strip():
+            raise RuntimeError(f"Failed to inspect image {image}: {inspect_result.stderr.strip()}")
+
+        # Extract and print the digest
+        digest = inspect_result.stdout.strip().split('@')[-1].replace('"', '')
+        print(digest)
+
+        # Remove the image after use
+        subprocess.run(["docker", "rmi", image], check=False)
+
+        return digest
+
+    except Exception as e:
+        print(f"Error: {e}")
+        return None
 
 def determine_base_image(container_id):
     try:
@@ -123,7 +120,7 @@ def determine_base_image(container_id):
 
 def get_container_id(image):
     try:
-        response = subprocess.run(["docker", "run", "--rm", "-t", "-d", image], capture_output=True, text=True)
+        response = subprocess.run(["docker", "run", "-t", "-d", "--entrypoint=cat", image], capture_output=True, text=True)
         container_id = response.stdout.strip()
         return container_id
     except Exception:
@@ -192,16 +189,15 @@ def static_analysis(username, password, url, insecure, image, aws_s3_bucket_uplo
 
     if profile == "auto":
         profile = determine_base_image(container_id)
-        print(profile)
     if profile == "indeterminate":
         print("No automatic profile available, please specify a profile to continue.")
-        exit()
-    
+        exit(1)
+
     package_name = "anchorestig"
     spec = importlib.util.find_spec(package_name)
     package_root_directory = os.path.dirname(spec.origin)
 
-    if profile == "ubi8" or profile == "ubi9" or profile == "ubuntu2004" or profile == "ubuntu2204":
+    if profile == "ubi8" or profile == "ubi9" or profile == "ubuntu2004" or profile == "ubuntu2204" or profile == "nginx" or profile == "crunchy-postgresql" or profile == "jboss" or profile == "jre7" or profile == "mongodb" or profile == "postgres9":
         policy_path = f"{package_root_directory}/policies/{profile}/anchore-{profile}-disa-stig-1.0.0.tar.gz"
     else:
         policy_path = profile
